package com.supwisdom.dlpay.consume;

import com.supwisdom.dlpay.consume.domain.TAccount;
import com.supwisdom.dlpay.consume.domain.TPerson;
import com.supwisdom.dlpay.framework.service.PersonPayService;
import com.supwisdom.dlpay.framework.util.TradeDict;

import java.util.ArrayList;
import java.util.List;

public class PayDtlBuilder {
  public static class PayDetail {
    private String accNo;
    private String accName;
    private Double amount;
    private String direction;
    private String summary;
  }

  private TPerson person;
  private TAccount account;
  private String direction;

  private Double payAmount;

  private String summary;

  private List<PayDetail> detail;

  public static PayDtlBuilder newBuilder() {
    return new PayDtlBuilder();
  }

  private PayDtlBuilder() {
    this.detail = new ArrayList<>();
  }

  public PayDtlBuilder person(TPerson per, TAccount acc, String direction) {
    this.person = per;
    this.account = acc;
    this.direction = direction;
    return this;
  }

  public PayDtlBuilder setSummary(String s) {
    this.summary = s;
    return this;
  }

  public PayDtlBuilder setTransDatetime(String transDate ,String transTime) {

    return this;
  }

  public Boolean done(PersonPayService service) {
    if (this.detail.size() == 0) {
      return false;
    }
    this.payAmount = 0.0;

    for (PayDetail d : detail) {
      this.payAmount += d.amount;
    }
    if (this.payAmount > this.account.getBalance()) {
      return false;
    }
    service.process(this);
    return true;
  }


  public PayDtlBuilder addSubDtl(String accNo, Double amount, String summary) {
    PayDetail dtl = new PayDetail();
    dtl.accNo = accNo;
    dtl.accName = "";
    dtl.amount = amount;
    if (this.direction.equals(TradeDict.TRANS_DIRECTION_CREDIT)) {
      dtl.direction = TradeDict.TRANS_DIRECTION_DEBIT;
    } else {
      dtl.direction = TradeDict.TRANS_DIRECTION_CREDIT;
    }
    dtl.summary = summary;
    this.detail.add(dtl);
    return this;
  }
}
